@@ -175,3 +175,17 @@ void CleaN900::on_pushUpTem_clicked()
     process.start("sh uptemp.sh");
     process.waitForFinished();
 }
+
+void CleaN900::on_pushPart_clicked()
+{
+    QProcess process;
+    process.start("sh fsck.sh");
+    process.waitForFinished();
+}
+
+void CleaN900::on_pushDet_clicked()
+{
+    QProcess process;
+    process.start("sh signal.sh");
+    process.waitForFinished();
+}
