@@ -19,6 +19,8 @@ private:
     Ui::CleaN900 *ui;
 
 private slots:
+    void on_pushDet_clicked();
+    void on_pushPart_clicked();
     void on_pushUpTem_clicked();
     void on_pushApp_clicked();
     void on_pushBat_clicked();
